@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: clustal-omega.c 290 2013-09-20 15:18:12Z fabian $
+ *  RCS $Id: clustal-omega.c 304 2016-06-13 13:39:13Z fabian $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -207,7 +207,8 @@ SetDefaultAlnOpts(opts_t *prOpts) {
 
     prOpts->ppcHMMInput = NULL;
     prOpts->iHMMInputFiles = 0;
-		
+    prOpts->pcHMMBatch = NULL; /* FS, r291 -> */
+
     prOpts->iNumIterations = 0;
     prOpts->bIterationsAuto = FALSE;
     prOpts->iMaxGuidetreeIterations = INT_MAX;
@@ -958,7 +959,7 @@ SetAutoOptions(opts_t *prOpts, int iNumSeq) {
 int
 Align(mseq_t *prMSeq, 
       mseq_t *prMSeqProfile,
-      opts_t *prOpts) {
+      opts_t *prOpts) { /* Note DEVEL 291: at this stage pppcHMMBNames is set but ppiHMMBindex is not */
    
     /* HMM
      */
@@ -980,6 +981,10 @@ Align(mseq_t *prMSeq,
     /* last dAlnScore for iteration */
     double dLastAlnScore = -666.666;
 
+    /* HMM batch file */
+    char **ppcHMMbatch = NULL; /* names of unique HMM files */
+    int iHMMbatch = 0; /* number of unique HMM files */
+
     int i, j; /* aux */
 
     assert(NULL != prMSeq);
@@ -1027,17 +1032,57 @@ Align(mseq_t *prMSeq,
     }
 
 
-    /* Read backgrounds HMMs and store in prHMMs
+    /* Read backgrounds HMMs and store in prHMMs (Devel 291)
      *
      */
-    if (0 < prOpts->iHMMInputFiles) {
+    if (NULL != prOpts->pcHMMBatch){
+        int i, j, k;
+
+        for (i = 0; i < prMSeq->nseqs; i++){ 
+
+            if (NULL != prMSeq->pppcHMMBNames[i]){ 
+                for (j = 0; NULL != prMSeq->pppcHMMBNames[i][j]; j++){ 
+                    
+                    for (k = 0; k < iHMMbatch; k++){ 
+                        if (0 == strcmp(ppcHMMbatch[k], prMSeq->pppcHMMBNames[i][j])){
+                            prMSeq->ppiHMMBindex[i][j] = k;
+                            break; /* HMM already registered */
+                        }
+                    } /* went through HMM batch files already identified */
+                    if (k == iHMMbatch){
+                        FILE *pfHMM = NULL; 
+                        if (NULL == (pfHMM = fopen(prMSeq->pppcHMMBNames[i][j], "r"))){ 
+                            prMSeq->ppiHMMBindex[i][j] = -1;
+                            Log(&rLog, LOG_WARN, "Background HMM %s for %s (%d/%d) does not exist", 
+                                prMSeq->pppcHMMBNames[i][j], prMSeq->sqinfo[i].name, i, j);
+                        } 
+                        else { 
+                            fclose(pfHMM); pfHMM = NULL;
+                            ppcHMMbatch = (char **)realloc(ppcHMMbatch, (iHMMbatch+1)*sizeof(char *));
+                            ppcHMMbatch[iHMMbatch] = strdup(prMSeq->pppcHMMBNames[i][j]);
+                            prMSeq->ppiHMMBindex[i][j] = k;
+                            iHMMbatch++;
+                        }
+                    }
+
+                } /* j = 0; NULL != prMSeq->pppcHMMBNames[i][j] */
+            } /* NULL != prMSeq->pppcHMMBNames[i] */
+            else {
+                /* void */
+            }
+        } /* 0 <= i < prMSeq->nseqs */
+
+    } /* there was a HMM batch file */
+
+
+    if (0 < prOpts->iHMMInputFiles) {  
         int iHMMInfileIndex;
         
         /**
          * @warning old structure used to be initialised like this:
          * hmm_light rHMM = {0};
          */
-        prHMMs = (hmm_light *) CKMALLOC(prOpts->iHMMInputFiles * sizeof(hmm_light));
+        prHMMs = (hmm_light *) CKMALLOC( (prOpts->iHMMInputFiles) * sizeof(hmm_light));
         
         for (iHMMInfileIndex=0; iHMMInfileIndex<prOpts->iHMMInputFiles; iHMMInfileIndex++) {
             char *pcHMMInput = prOpts->ppcHMMInput[iHMMInfileIndex];
@@ -1077,6 +1122,24 @@ Align(mseq_t *prMSeq,
         CKFREE(prOpts->ppcHMMInput);
     } /* there were background HMM files */
     
+    /** read HMMs specific to individual sequences
+     */
+    if (iHMMbatch > 0){
+        int i;
+
+        prHMMs = (hmm_light *) realloc( prHMMs, (prOpts->iHMMInputFiles + iHMMbatch + 1) * sizeof(hmm_light));
+
+        for (i = 0; i < iHMMbatch; i++){
+            char *pcHMMInput = ppcHMMbatch[i];
+
+            if (OK != readHMMWrapper(&prHMMs[i + prOpts->iHMMInputFiles], pcHMMInput)){
+                Log(&rLog, LOG_ERROR, "Processing of HMM file %s failed", pcHMMInput);
+                return -1;
+            }
+
+        } /* 0 <= i < iHMMbatch */
+
+    } /* there were HMM batch files */
 
     
     /* If the input ("non-profile") sequences are aligned, then turn
@@ -1172,6 +1235,9 @@ Align(mseq_t *prMSeq,
     if (prOpts->iMaxHMMIterations < 0){
         Log(&rLog, LOG_VERBOSE,
             "iMaxHMMIterations < 0 (%d), will not perform alignment", prOpts->iMaxHMMIterations);
+        if (NULL != piOrderLR){
+            free(piOrderLR); piOrderLR = NULL;
+        }
         return 0;
     }
 
