@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: hhalign_wrapper.c 290 2013-09-20 15:18:12Z fabian $
+ *  RCS $Id: hhalign_wrapper.c 306 2016-06-13 13:49:04Z fabian $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,7 +50,7 @@
  */
 void SetDefaultHhalignPara(hhalign_para *prHhalignPara)
 {
-    prHhalignPara->iMacRamMB = 2048;  /* 2048 default|give 2GB to MAC algorithm */
+    prHhalignPara->iMacRamMB = 8000;  /* default|give just under 8GB to MAC algorithm, FS, 2016-04-18, went from 2GB to 8GB */
     prHhalignPara->bIsDna = false; /* protein mode unless we say otherwise */	
     prHhalignPara->bIsRna = false;	
     prHhalignPara->pca = -UNITY;
@@ -550,7 +550,8 @@ PosteriorProbabilities(mseq_t *prMSeq, hmm_light rHMMalignment, hhalign_para rHh
         zcError[0] = '\0';
         hhalign(ppcCopy, 1, NULL, 
                 ppcRepresent, 0, NULL, 
-                &dScore, &rHMMalignment, NULL, NULL, NULL, NULL,
+                &dScore, &rHMMalignment, &rHMMalignment, 
+                NULL, NULL, NULL, NULL,
                 rHhalignPara, &prHHscores[iS], 0/* debug */, FALSE /* Log-Level*/, 
                 zcAux, zcError);
         if (NULL != strstr(zcError, "Viterbi")){
@@ -682,7 +683,7 @@ PileUp(mseq_t *prMSeq, hhalign_para rHhalignPara, int iClustersize)
          * external HMM not used at this stage (prHMM=NULL) */
         iHHret = hhalign(ppcProfilePro, iI, NULL/*pdWeightL*/,
                          ppcProfileSeq,  1, NULL/*pdWeightR*/,
-                         &dScore, prHMM,
+                         &dScore, prHMM, prHMM,
                          pcConsensPro, pcReprsntPro,
                          pcConsensSeq, pcReprsntSeq,
                          rHhalignPara, &rHHscores,
@@ -732,7 +733,7 @@ PileUp(mseq_t *prMSeq, hhalign_para rHhalignPara, int iClustersize)
         prHMM = &rHMMprofile;
         hhalign(ppcReprsnt, 0, NULL,
                 ppcProfileSeq, 1, NULL, 
-                &dScore, prHMM,
+                &dScore, prHMM, prHMM,
                 pcConsensPro, pcReprsntPro,
                 pcConsensSeq, pcReprsntSeq,
                 rHhalignPara, &rHHscores,
@@ -893,7 +894,10 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
     double *pdWeightsL = NULL; /* sequence weights of left  profile */
     double *pdWeightsR = NULL; /* sequence weights of right profile */
     int iMergeNodeCounter = 0;
-    hmm_light *prHMM = NULL;
+    hmm_light *prHMM = NULL; 
+    hmm_light *prHMMleft = NULL;
+    hmm_light *prHMMrght = NULL;
+    hmm_light *prHMMnull = NULL;
     bool bPrintCR = (rLog.iLogLevelEnabled<=LOG_VERBOSE) ? FALSE : TRUE;
 #if TIMING
     char zcStopwatchMsg[1024];
@@ -903,15 +907,28 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
 #endif
     hhalign_scores rHHscores = {0};
 
-    if (NULL != prHMMList) {
+#if 0 /* DEVEL 291 */
+    if (NULL != prHMMList) { /* FIXME DEVEL 291: replace this outer test with iHMMCount>0*/
         if (iHMMCount>1) {
             Log(&rLog, LOG_WARN, "FIXME: Using only first of %u HMMs (needs implementation)", iHMMCount);
         }
-        prHMM = &(prHMMList[0]);
+        prHMM = &(prHMMList[0]); /* FIXME DEVEL 291: check for NULL */
     } else {
         /* FIXME: prHMM not allowed to be NULL and therefore pseudo allocated here */
         prHMM = (hmm_light *) CKCALLOC(1, sizeof(hmm_light));
     }
+#else
+    prHMMnull = (hmm_light *) CKCALLOC(1, sizeof(hmm_light));
+    if ( (iHMMCount > 0) && (NULL != prHMMList) ){
+        prHMM = &(prHMMList[0]);
+        if (iHMMCount > 1) {
+            Log(&rLog, LOG_WARN, "FIXME: Using only first of %u HMMs (needs implementation)", iHMMCount);
+        }
+    }
+    else {
+        prHMM = prHMMnull; /* prHMM not allowed to be NULL and therefore assigned to pseudo allocated  */
+    }
+#endif
     
     assert(NULL!=prMSeq);
     
@@ -1075,7 +1092,38 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                 }
             }
 
+#if 1 /* DEVEL 291 */
+            /*
+             * Note: if there is a HMM-batch file, then prMSeq->ppiHMMBindex is not NULL;
+             *       ppiLeafList[iL/iR][0] is the 'lead' sequence in a profile;
+             *       prMSeq->ppiHMMBindex[ppiLeafList[iL][0]] are the HMMs associated with the lead sequence;
+             *         this could be NULL if there are no HMMs associated with this particular sequence
+             *       at the moment only 1st HMM can be used, prMSeq->ppiHMMBindex[ppiLeafList[iL][0]][0];
+             *         the index of this HMM can be '-1' if the specified HMM file does not exist
+             * Note: we only use prHMMleft/prHMMrght, even if global HMM (--hmm-in) is specified
+             **/
+            if ( (NULL != prMSeq->ppiHMMBindex) && (NULL != prMSeq->ppiHMMBindex[ppiLeafList[iL][0]]) && 
+                 (prMSeq->ppiHMMBindex[ppiLeafList[iL][0]][0] > -1) ){
+                prHMMleft = &(prHMMList[prMSeq->ppiHMMBindex[ppiLeafList[iL][0]][0]]);
+            }
+            else if (iHMMCount > 0){
+                prHMMleft = prHMM;
+            }
+            else {
+                prHMMleft = prHMMnull;
+            }
 
+            if ( (NULL != prMSeq->ppiHMMBindex) && (NULL != prMSeq->ppiHMMBindex[ppiLeafList[iR][0]]) &&
+                 (prMSeq->ppiHMMBindex[ppiLeafList[iR][0]][0] > -1) ){
+                prHMMrght = &(prHMMList[prMSeq->ppiHMMBindex[ppiLeafList[iR][0]][0]]);
+            }
+            else if (iHMMCount > 0){
+                prHMMrght = prHMM;
+            }
+            else {
+                prHMMrght = prHMMnull;
+            }
+#endif
             
             /* align individual sequences to HMM;
              * - use representative sequence to get gapping
@@ -1086,15 +1134,16 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
              * full HMM but that does not seem to work at all
              * -- try harder! Fail better!
              */
-            if ( (piLeafCount[iL] <= APPLY_BG_HMM_UP_TO_TREE_DEPTH) && (0 != prHMM->L) ){
+            /*if ( (piLeafCount[iL] <= APPLY_BG_HMM_UP_TO_TREE_DEPTH) && (0 != prHMM->L) ){*/
+            if (0 != prHMMleft->L){
                 int i, j;
-                pcReprsnt1 = CKCALLOC(prHMM->L+strlen(ppcProfile1[0])+1, sizeof(char));
-                for (i = 0; i < prHMM->L; i++){
-                    pcReprsnt1[i] = prHMM->seq[prHMM->ncons][i+1];
+                pcReprsnt1 = CKCALLOC(prHMMleft->L+strlen(ppcProfile1[0])+1, sizeof(char));
+                for (i = 0; i < prHMMleft->L; i++){
+                    pcReprsnt1[i] = prHMMleft->seq[prHMMleft->ncons][i+1];
                 }
                 ppcCopy1 = CKCALLOC(piLeafCount[iL], sizeof(char *));
                 for (j = 0; j < piLeafCount[iL]; j++){
-                    ppcCopy1[j] = CKCALLOC(prHMM->L+strlen(ppcProfile1[0])+1, sizeof(char));
+                    ppcCopy1[j] = CKCALLOC(prHMMleft->L+strlen(ppcProfile1[0])+1, sizeof(char));
                     for (i = 0; i < (int) strlen(ppcProfile1[0]); i++){
                         ppcCopy1[j][i] = ppcProfile1[j][i];
                     }
@@ -1118,13 +1167,13 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                        FS, r236 -> r237
                     */
                     int iLenA = strlen(ppcCopy1[0]);
-                    int iLenH = prHMM->L;
+                    int iLenH = prHMMleft->L;
                     int iHHret = 0;
                     
                     if (iLenH < iLenA){
                         iHHret = hhalign(ppcReprsnt1, 0/* only one representative seq*/, NULL,
                                          ppcCopy1, piLeafCount[iL], pdWeightsL,
-                                         &dScore, prHMM,
+                                         &dScore, prHMMleft, prHMMleft,
                                          NULL, NULL, NULL, NULL,
                                          rHhalignPara, &rHHscores, 
                                          iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
@@ -1133,7 +1182,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                     else {
                         iHHret = hhalign(ppcCopy1, piLeafCount[iL], pdWeightsL,
                                          ppcReprsnt1, 0/* only one representative seq*/, NULL,
-                                         &dScore, prHMM,
+                                         &dScore, prHMMleft, prHMMleft,
                                          NULL, NULL, NULL, NULL,
                                          rHhalignPara, &rHHscores, 
                                          iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
@@ -1159,8 +1208,8 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                  * it only contains a gap if all sequences of the profile
                  * have a gap at this position
                  */
-                pcConsens1 = CKCALLOC(prHMM->L+strlen(ppcProfile1[0])+1, sizeof(char));
-                for (i = 0; i < prHMM->L; i++){
+                pcConsens1 = CKCALLOC(prHMMleft->L+strlen(ppcProfile1[0])+1, sizeof(char));
+                for (i = 0; i < prHMMleft->L; i++){
                     for (j = 0, pcConsens1[i] = '-'; (j < piLeafCount[iL]) && ('-' == pcConsens1[i]); j++){
                         pcConsens1[i] = ppcCopy1[j][i];
                     }
@@ -1173,16 +1222,17 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
 #endif
             } /* ( (1 == piLeafCount[iL]) && (0 != prHMM->L) ) */
 
-            if ( (piLeafCount[iR] <= APPLY_BG_HMM_UP_TO_TREE_DEPTH) && (0 != prHMM->L) ){
+            /*if ( (piLeafCount[iR] <= APPLY_BG_HMM_UP_TO_TREE_DEPTH) && (0 != prHMM->L) ){*/
+            if (0 != prHMMrght->L){
                 int i, j;
 
-                pcReprsnt2 = CKCALLOC(prHMM->L+strlen(ppcProfile2[0])+1, sizeof(char));
-                for (i = 0; i < prHMM->L; i++){
-                    pcReprsnt2[i] = prHMM->seq[prHMM->ncons][i+1];
+                pcReprsnt2 = CKCALLOC(prHMMrght->L+strlen(ppcProfile2[0])+1, sizeof(char));
+                for (i = 0; i < prHMMrght->L; i++){
+                    pcReprsnt2[i] = prHMMrght->seq[prHMMrght->ncons][i+1];
                 }
                 ppcCopy2 = CKCALLOC(piLeafCount[iR], sizeof(char *));
                 for (j = 0; j < piLeafCount[iR]; j++){
-                    ppcCopy2[j] = CKCALLOC(prHMM->L+strlen(ppcProfile2[0])+1, sizeof(char));
+                    ppcCopy2[j] = CKCALLOC(prHMMrght->L+strlen(ppcProfile2[0])+1, sizeof(char));
                     for (i = 0; i < (int) strlen(ppcProfile2[0]); i++){
                         ppcCopy2[j][i] = ppcProfile2[j][i];
                     }
@@ -1206,13 +1256,13 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                        FS, r236 -> r237
                     */
                     int iLenA = strlen(ppcCopy2[0]);
-                    int iLenH = prHMM->L;
+                    int iLenH = prHMMrght->L;
                     int iHHret = 0;
 
                     if (iLenH < iLenA){
                         iHHret = hhalign(ppcReprsnt2, 0/* only one representative seq */, NULL,
                                          ppcCopy2,    piLeafCount[iR], pdWeightsR,
-                                         &dScore, prHMM,
+                                         &dScore, prHMMrght, prHMMrght,
                                          NULL, NULL, NULL, NULL,
                                          rHhalignPara, &rHHscores, 
                                          iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
@@ -1221,7 +1271,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                     else {
                         iHHret = hhalign(ppcCopy2,    piLeafCount[iR], pdWeightsR,
                                          ppcReprsnt2, 0/* only one representative seq */, NULL,
-                                         &dScore, prHMM,
+                                         &dScore, prHMMrght, prHMMrght,
                                          NULL, NULL, NULL, NULL,
                                          rHhalignPara, &rHHscores, 
                                          iAux_FS++, /* DEBUG ARGUMENT */ rLog.iLogLevelEnabled,
@@ -1247,8 +1297,8 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                  * it only contains a gap if all sequences of the profile
                  * have a gap at this position
                  */
-                pcConsens2 = CKCALLOC(prHMM->L+strlen(ppcProfile2[0])+1, sizeof(char));
-                for (i = 0; i < prHMM->L; i++){
+                pcConsens2 = CKCALLOC(prHMMrght->L+strlen(ppcProfile2[0])+1, sizeof(char));
+                for (i = 0; i < prHMMrght->L; i++){
                     for (j = 0, pcConsens2[i] = '-'; (j < piLeafCount[iR]) && ('-' == pcConsens2[i]); j++){
                         pcConsens2[i] = ppcCopy2[j][i];
                     }
@@ -1291,7 +1341,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                     int iOldMacRam = rHhalignPara.iMacRamMB;
                     iHHret = hhalign(ppcProfile1, piLeafCount[iL], pdWeightsL,
                                      ppcProfile2, piLeafCount[iR], pdWeightsR,
-                                     &dScore, prHMM,
+                                     &dScore, prHMMleft, prHMMrght,
                                      pcConsens1, pcReprsnt1,
                                      pcConsens2, pcReprsnt2,
                                      rHhalignPara, &rHHscores, 
@@ -1310,6 +1360,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                            the only thing we can do (easily) is to re-run it in Viterbi mode, 
                            for this set MAC-RAM=0, set it back to its original value after 2nd try. 
                            FS, r241 -> r243 */
+
                         if (RETURN_FROM_MAC == iHHret){
                             /* Note: the default way to run hhalign() is to initially select MAC 
                                by giving it all the memory it needs. MAC may fail due to overflow (repeats?).
@@ -1328,7 +1379,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
 
                         iHHret = hhalign(ppcProfile1, piLeafCount[iL], pdWeightsL,
                                          ppcProfile2, piLeafCount[iR], pdWeightsR,
-                                         &dScore, prHMM,
+                                         &dScore, prHMMleft, prHMMrght,
                                          pcConsens1, pcReprsnt1,
                                          pcConsens2, pcReprsnt2,
                                          rHhalignPara, &rHHscores, 
@@ -1353,7 +1404,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                     int iOldMacRam = rHhalignPara.iMacRamMB;
                     iHHret = hhalign(ppcProfile2, piLeafCount[iR], pdWeightsR,
                                      ppcProfile1, piLeafCount[iL], pdWeightsL,
-                                     &dScore, prHMM,
+                                     &dScore, prHMMrght, prHMMleft,
                                      pcConsens2, pcReprsnt2,
                                      pcConsens1, pcReprsnt1,
                                      rHhalignPara, &rHHscores, 
@@ -1372,6 +1423,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                            the only thing we can do (easily) is to re-run it in Viterbi mode, 
                            for this set MAC-RAM=0, set it back to its original value after 2nd try. 
                            FS, r241 -> r243 */
+
                         if (RETURN_FROM_MAC == iHHret){
                             /* see above */
                             rHhalignPara.iMacRamMB = 0;
@@ -1382,7 +1434,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
 
                         iHHret = hhalign(ppcProfile2, piLeafCount[iR], pdWeightsR,
                                          ppcProfile1, piLeafCount[iL], pdWeightsL,
-                                         &dScore, prHMM,
+                                         &dScore, prHMMrght, prHMMleft,
                                          pcConsens2, pcReprsnt2,
                                          pcConsens1, pcReprsnt1,
                                          rHhalignPara, &rHHscores, 
@@ -1402,7 +1454,56 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                     } /* 1st invocation failed */
 
                 } /* 2nd profile was shorter than 1st */
-            
+
+                /* 
+                 * at this stage have performed alignment of 2 profiles/sequences.
+                 * if HMM batch information had been used then have choices:
+                 * (i) if HMM info only intended for initial alignment (of sequences) then make both HMMs stale;
+                 * (iia) if alignment of 2 profiles/sequences where same HMM used, then retain;
+                 * (iib) if alignment of 2 profiles/sequences where different HMMs used, then make both stale;
+                 * (iii) some majority voting
+                 */
+#if 0  /* always make HMM batch stale (after 1st invocation) */
+                if ( (NULL != prMSeq->ppiHMMBindex) && (NULL != prMSeq->ppiHMMBindex[ppiLeafList[iL][0]]) ){
+                    prMSeq->ppiHMMBindex[ppiLeafList[iL][0]][0] = -1;
+                }
+                if ( (NULL != prMSeq->ppiHMMBindex) && (NULL != prMSeq->ppiHMMBindex[ppiLeafList[iR][0]]) ){
+                    prMSeq->ppiHMMBindex[ppiLeafList[iR][0]][0] = -1;
+                }
+#else /* retain HMMs if they were the same for both profiles */
+                if (NULL != prMSeq->ppiHMMBindex) {
+                    int i;
+
+                    if ( (NULL != prMSeq->ppiHMMBindex[ppiLeafList[iL][0]]) && (NULL != prMSeq->ppiHMMBindex[ppiLeafList[iR][0]]) ){
+                        if ( prMSeq->ppiHMMBindex[ppiLeafList[iL][0]][0] == -1){
+                            prMSeq->ppiHMMBindex[ppiLeafList[iR][0]][0] = -1; /* this is conservative, could do H[iL] = H[iR] */
+                            for (i = 0; i < piLeafCount[iR]; i++){
+                                prMSeq->ppiHMMBindex[ppiLeafList[iR][i]][0] = -1;
+                            }
+                        }
+                        else if ( prMSeq->ppiHMMBindex[ppiLeafList[iR][0]][0] == -1){
+                            prMSeq->ppiHMMBindex[ppiLeafList[iL][0]][0] = -1; /* this is conservative, could do H[iR] = H[iL] */
+                            for (i = 0; i < piLeafCount[iL]; i++){
+                                prMSeq->ppiHMMBindex[ppiLeafList[iL][i]][0] = -1;
+                            }
+                        }
+                        else if (prMSeq->ppiHMMBindex[ppiLeafList[iL][0]][0] != prMSeq->ppiHMMBindex[ppiLeafList[iR][0]][0]){
+                            prMSeq->ppiHMMBindex[ppiLeafList[iL][0]][0] = -1; /* this is NOT conservative, mandatory */
+                            for (i = 0; i < piLeafCount[iL]; i++){
+                                prMSeq->ppiHMMBindex[ppiLeafList[iL][i]][0] = -1;
+                            }
+                            prMSeq->ppiHMMBindex[ppiLeafList[iR][0]][0] = -1; /* this is NOT conservative, mandatory */
+                            for (i = 0; i < piLeafCount[iR]; i++){
+                                prMSeq->ppiHMMBindex[ppiLeafList[iR][i]][0] = -1;
+                            }
+                        }
+                        else {
+                            /* void, HMMs should be same */
+                        }
+                    }
+                } /* there was a HMM batch */
+#endif
+                
                 if (rLog.iLogLevelEnabled <= LOG_DEBUG){
                     int i;
 
@@ -1513,9 +1614,13 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
     TranslateUnknown2Ambiguity(prMSeq);
     ReAttachLeadingGaps(prMSeq, iProfProfSeparator);
 
+#if 0 /* DEVEL 291 */
     if (NULL == prHMMList){
         CKFREE(prHMM);
     }
+#else
+    CKFREE(prHMMnull);
+#endif
     CKFREE(ppcProfile2);
     CKFREE(ppcProfile1);
     CKFREE(ppiLeafList[piOrderLR[DIFF_NODE*(iNodeCount-1)+PRNT_NODE]]);
