@@ -13,9 +13,17 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: hhalign_wrapper.h 259 2011-08-04 15:14:30Z fabian $
+ *  RCS $Id: hhalign_wrapper.h 289 2013-09-17 10:09:37Z fabian $
  */
 
+extern void
+SetDefaultHhalignPara(hhalign_para *prHhalignPara);
+
+extern int
+PosteriorProbabilities(mseq_t *prMSeq, hmm_light rHMMalignment, hhalign_para rHhalignPara, char *pcPosteriorfile);
+
+extern double 
+PileUp(mseq_t *prMSeq, hhalign_para rHhalignPara, int iClustersize);
 
 extern double
 HHalignWrapper(mseq_t *mseq, int *piOrderLR,
