@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: ktuple_pair.c 230 2011-04-09 15:37:50Z andreas $
+ *  RCS $Id: ktuple_pair.c 305 2016-06-13 13:46:02Z fabian $
  *
  *
  * K-Tuple code for pairwise alignment (Wilbur and Lipman, 1983; PMID
@@ -649,7 +649,7 @@ KTuplePairDist(symmatrix_t *tmat, mseq_t *mseq,
     /* int uStepNo, uTotalStepNo; */
     ktuple_param_t aln_param = default_protein_param;
     bool bPrintCR = (rLog.iLogLevelEnabled<=LOG_VERBOSE) ? FALSE : TRUE;
-
+    
 
     if(prProgress == NULL) {
         NewProgress(&prProgress, LogGetFP(&rLog, LOG_INFO), 
@@ -822,7 +822,9 @@ KTuplePairDist(symmatrix_t *tmat, mseq_t *mseq,
     #pragma omp critical(ktuple)
 #if 0
     {
-    printf("steps: %d\n", private_step_no);
+        int tid;
+        tid = omp_get_thread_num();
+        printf("%s:%d: tid %d: steps %d\n", __FILE__, __LINE__, tid, private_step_no);
     }
 #endif
 #endif
