@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: mbed.c 300 2016-06-13 13:29:58Z fabian $
+ *  RCS $Id: mbed.c 316 2016-12-16 16:14:39Z fabian $
  *
  *
  * Reimplementation from scratch of mBed (Blackshields et al., 2010;
@@ -88,8 +88,10 @@ static const int RESTARTS_PER_SPLIT = 10;
 #define USE_KMEANS_LLOYDS 0
 
 
-#ifndef HAVE_LOG2
-#define log2(x)  (log(x) / 0.69314718055994530942)
+//#ifndef HAVE_LOG2
+#ifndef CLUSTAL_OMEGA_HAVE_LOG2
+//#define log2(x)  (log(x) / 0.69314718055994530942)
+#define log2(x)  ( x<=0 ? (float)(-100000) : 1.442695041*log(x) )
 #endif
 #define NUMBER_OF_SEEDS(n) pow(log2(((double)n)), 2)
 
