@@ -13,7 +13,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: mbed.h 193 2011-02-07 15:45:21Z andreas $
+ *  RCS $Id: mbed.h 278 2013-05-16 15:53:45Z fabian $
  */
 
 #ifndef CLUSTALO_MBED_H
@@ -25,6 +25,7 @@
 
 extern int
 Mbed(tree_t **tree, mseq_t *prMSeq,
-     const int iPairDistType, const char *pcGuidetreeOutfile);
+     const int iPairDistType, const char *pcGuidetreeOutfile,
+     int iClustersizes, const char *pcClusterFile);
 
 #endif
