@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: seq.c 291 2014-02-27 18:20:54Z fabian $
+ *  RCS $Id: seq.c 298 2014-11-07 12:18:36Z fabian $
  *
  *
  * Module for sequence/alignment IO and misc.
@@ -37,7 +37,7 @@
 #include "util.h"
 #include "log.h"
 #include "seq.h"
-
+/*#include "../../mymemmonitor.h"*/
 
 #define ALLOW_ONLY_PROTEIN 0 // DD
 
@@ -419,11 +419,11 @@ SeqTypeToStr(int iSeqType)
 int
 ReadSequences(mseq_t *prMSeq, char *seqfile, 
               int iSeqType, int iSeqFmt, bool bIsProfile, bool bDealignInputSeqs, 
-              int iMaxNumSeq, int iMaxSeqLen)
+              int iMaxNumSeq, int iMaxSeqLen, char *pcHMMBatch)
 {
     SQFILE *dbfp; /* sequence file descriptor */
-    char *cur_seq;
-    SQINFO cur_sqinfo;
+    char *cur_seq = NULL;
+    SQINFO cur_sqinfo = {0};
     int iSeqIdx; /* sequence counter */
     int iSeqPos; /* sequence string position counter */
     
@@ -462,8 +462,8 @@ ReadSequences(mseq_t *prMSeq, char *seqfile,
      */
     while (ReadSeq(dbfp, dbfp->format,
                    &cur_seq,
-                   &cur_sqinfo)) {
-
+                   &cur_sqinfo)) { 
+        
         if (prMSeq->nseqs+1>iMaxNumSeq) {
             Log(&rLog, LOG_ERROR, "Maximum number of sequences (=%d) exceeded after reading sequence '%s' from '%s'",
                   iMaxNumSeq, cur_sqinfo.name, seqfile);
@@ -489,7 +489,8 @@ ReadSequences(mseq_t *prMSeq, char *seqfile,
         
 
         prMSeq->sqinfo =  (SQINFO *)
-            CKREALLOC(prMSeq->sqinfo, (prMSeq->nseqs+1) * sizeof(SQINFO));
+            CKREALLOC(prMSeq->sqinfo, (prMSeq->nseqs+1) * sizeof(SQINFO)); 
+        memset(&prMSeq->sqinfo[prMSeq->nseqs], 0, sizeof(SQINFO));
         SeqinfoCopy(&prMSeq->sqinfo[prMSeq->nseqs], &cur_sqinfo);
 
 #ifdef TRACE
@@ -549,7 +550,7 @@ ReadSequences(mseq_t *prMSeq, char *seqfile,
 
         prMSeq->nseqs++;
 
-        FreeSequence(cur_seq, &cur_sqinfo);        
+        FreeSequence(cur_seq, &cur_sqinfo); 
     }
     SeqfileClose(dbfp);
 
@@ -616,6 +617,83 @@ ReadSequences(mseq_t *prMSeq, char *seqfile,
     Log(&rLog, LOG_INFO, "Read %d sequences (type: %s) from %s",
          prMSeq->nseqs, SeqTypeToStr(prMSeq->seqtype), prMSeq->filename);
 
+    prMSeq->pppcHMMBNames = NULL;
+    prMSeq->ppiHMMBindex = NULL;
+
+    /* read HMM-batch file if existent */
+    if (NULL != pcHMMBatch) {
+
+        enum {MAXLINE=10000};
+        FILE *pfHMMBatch = NULL;
+        char zcScanline[MAXLINE] = {0};
+        char *pcToken = NULL;
+        char *pcSeqName = NULL;
+        int iSeq = 0;
+
+        /* check that file exists */
+        if (NULL == (pfHMMBatch = fopen(pcHMMBatch, "r"))){
+            Log(&rLog, LOG_ERROR, "Failed to open HMM-batch file %s for reading", pcHMMBatch);
+            return -1;
+        }
+
+        /* initialise names and indices */
+        prMSeq->pppcHMMBNames = (char ***)CKMALLOC(prMSeq->nseqs * sizeof(char **));
+        for (iSeq = 0; iSeq < prMSeq->nseqs; iSeq++){
+            prMSeq->pppcHMMBNames[iSeq] = NULL;
+        }
+        prMSeq->ppiHMMBindex = (int **)CKMALLOC(prMSeq->nseqs * sizeof(int *));
+        for (iSeq = 0; iSeq < prMSeq->nseqs; iSeq++){
+            prMSeq->ppiHMMBindex[iSeq] = (int *)CKMALLOC(1 * sizeof(int));
+            prMSeq->ppiHMMBindex[iSeq][0] = -1;
+        }
+
+        /* read batch file line-by-line */
+        while (NULL != fgets(zcScanline, MAXLINE, pfHMMBatch)){
+
+            pcToken = strtok(zcScanline, " \040\t\n");
+            if (NULL == pcToken){
+                continue;
+            }
+            else {
+                pcSeqName = pcToken;
+            }
+            /* identify sequence label from batch file in labels read from sequence file */
+            for (iSeq = 0; iSeq < prMSeq->nseqs; iSeq++){
+                int iHMM = 0;
+
+                if (0 == strcmp(pcSeqName, prMSeq->sqinfo[iSeq].name)){
+
+                    while (NULL != (pcToken = strtok(NULL, " \040\t\n"))){
+                        prMSeq->pppcHMMBNames[iSeq] = (char **)CKREALLOC(prMSeq->pppcHMMBNames[iSeq], 
+                                                                         (iHMM+2) * sizeof(char *));
+                        prMSeq->pppcHMMBNames[iSeq][iHMM] = CkStrdup(pcToken);
+                        prMSeq->ppiHMMBindex[iSeq] = (int *)CKREALLOC(prMSeq->ppiHMMBindex[iSeq], 
+                                                                      (iHMM+2) * sizeof(int));
+                        prMSeq->ppiHMMBindex[iSeq][iHMM] = 0;
+                        iHMM++;
+                        prMSeq->pppcHMMBNames[iSeq][iHMM] = NULL;
+                        prMSeq->ppiHMMBindex[iSeq][iHMM] = 0;
+                    }
+                    break;
+                }
+
+            } /* 0 <= iSeq < prMSeq->nseqs */
+            if (iSeq >= prMSeq->nseqs) {
+                Log(&rLog, LOG_WARN,
+                    "sequence %s not found in input sequences (%s), will be ignored",
+                    pcSeqName, seqfile);
+            }
+
+        } /* !EOF */
+
+        fclose(pfHMMBatch); pfHMMBatch = NULL;
+
+    } /* there was a HMM batch file */
+    else {
+        prMSeq->pppcHMMBNames = NULL;
+        prMSeq->ppiHMMBindex = NULL;
+    } /* there was no HMM batch file */
+
     return 0;
 }
 /***   end: ReadSequences   ***/
@@ -644,6 +722,8 @@ NewMSeq(mseq_t **prMSeq)
 	(*prMSeq)->sqinfo = NULL;
 	(*prMSeq)->filename = NULL;
 	(*prMSeq)->tree_order = NULL;
+    (*prMSeq)->pppcHMMBNames = NULL;
+    (*prMSeq)->ppiHMMBindex = NULL;
 }
 /***   end: NewMSeq   ***/
 
@@ -765,6 +845,14 @@ FreeMSeq(mseq_t **mseq)
         CKFREE((*mseq)->tree_order);
     }
 
+    if (NULL != (*mseq)->pppcHMMBNames){ /* FS, r291 -> */
+        for (i = 0; (*mseq)->pppcHMMBNames[i] && (i < (*mseq)->nseqs); i++){
+            int iIter = 0;
+            for (iIter = 0; NULL != (*mseq)->pppcHMMBNames[i][iIter]; iIter++){
+                CKFREE((*mseq)->pppcHMMBNames[i][iIter]);
+            }
+        }
+    }
 	(*mseq)->seqtype = SEQTYPE_UNKNOWN;
 	(*mseq)->nseqs = 0;
 
