@@ -13,7 +13,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: seq.h 289 2013-09-17 10:09:37Z fabian $
+ *  RCS $Id: seq.h 296 2014-10-07 12:15:41Z fabian $
  */
 
 #ifndef CLUSTALO_SEQ_H
@@ -111,6 +111,10 @@ typedef struct {
      *
      */
     SQINFO *sqinfo; 
+
+  /* HMM batch information */
+  char ***pppcHMMBNames;
+  int **ppiHMMBindex;
 } mseq_t;
 
 extern void
@@ -131,7 +135,7 @@ SeqTypeToStr(int seqtype);
 extern int
 ReadSequences(mseq_t *prMSeq_p, char *pcSeqFile, 
               int iSeqType,  int iSeqFmt, bool bIsProfile, bool bDealignInputSeqs, 
-              int iMaxNumSeq, int iMaxSeqLen);
+              int iMaxNumSeq, int iMaxSeqLen, char *pcHMMBatch);
 
 extern void
 NewMSeq(mseq_t **mseq);
