@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: symmatrix.c 288 2013-07-29 13:15:50Z andreas $
+ *  RCS $Id: symmatrix.c 303 2016-06-13 13:37:47Z fabian $
  *
  *
  * Functions for symmetric (square) matrices including diagonal.
@@ -77,6 +77,10 @@ NewSymMatrix(symmatrix_t **symmat, int nrows, int ncols)
         fprintf(stderr, "Couldn't allocate memory (%s|%s)\n",
                 __FILE__, __FUNCTION__);
         return -1;
+    } 
+    else {
+        (*symmat)->nrows = nrows;
+        (*symmat)->ncols = ncols;
     }
     
     (*symmat)->data = (double **) malloc(nrows * sizeof(double *));
@@ -87,6 +91,38 @@ NewSymMatrix(symmatrix_t **symmat, int nrows, int ncols)
         *symmat = NULL;
         return -1;
     }
+
+#ifdef HAVE_OPENMP
+    /* one malloc for the full matrix data structure
+       assumes ncols >= nrows (asserted above) */
+    double *mat_data;
+    int elements_to_date=0;
+    if ((mat_data = (double *)malloc(((nrows+1)*nrows/2 + (ncols-nrows)*nrows) * sizeof(double))) == NULL) {
+        fprintf(stderr, "Couldn't allocate MPI memory (%s|%s)\n", __FILE__, __FUNCTION__); 
+        free((*symmat)->data);
+        free(*symmat);
+        *symmat = NULL;
+        return -1;
+    }
+    for (i=0; i<nrows; i++) {
+        (*symmat)->data[i] = &mat_data[elements_to_date];
+        elements_to_date += ncols-i;
+#ifdef TRACE
+        fprintf(stderr, "DEBUG(%s|%s():%d) initialising symmat with the number of the beast\n",
+                __FILE__, __FUNCTION__, __LINE__);
+#endif
+        {
+            int j;
+            for (j=0; j<ncols-i; j++) {
+#ifdef TRACE
+                (*symmat)->data[i][j] = -666.0;
+#else
+                (*symmat)->data[i][j] = 0.0;
+#endif
+            }
+        }
+    }
+#else  /* not HAVE_OPENMP */
     for (i=0; i<nrows; i++) {
         (*symmat)->data[i] = (double *) calloc((ncols-i), sizeof(double));
         if (NULL == (*symmat)->data[i]) {
@@ -112,10 +148,8 @@ NewSymMatrix(symmatrix_t **symmat, int nrows, int ncols)
         }
 #endif
     }
+#endif /* HAVE_OPENMP */
     
-    (*symmat)->nrows = nrows;
-    (*symmat)->ncols = ncols;
-
     return 0;
 }
 /***   end: new_symmatrix   ***/
@@ -242,12 +276,18 @@ SymMatrixGetValueP(double **val, symmatrix_t *symmat,
 void
 FreeSymMatrix(symmatrix_t **symmat)
 {
+#ifndef HAVE_OPENMP
     int i;
+#endif
     if (NULL != (*symmat)) {
         if (NULL != (*symmat)->data) {
+#ifdef HAVE_OPENMP
+            free((*symmat)->data[0]);
+#else
             for (i=0; i<(*symmat)->nrows; i++) {
                 free((*symmat)->data[i]);
             }
+#endif
             free((*symmat)->data);
         }
     }
