@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: clustalo-api-test.c 266 2011-10-20 16:04:11Z andreas $
+ *  RCS $Id: clustalo-api-test.c 280 2013-05-16 16:04:12Z fabian $
  */
 
 
@@ -92,7 +92,8 @@ main(int argc, char **argv)
 
     /* Output of final alignment to stdout (NULL) as aligned fasta/a2m
      */
-    if (WriteAlignment(prMSeq, NULL, MSAFILE_A2M)) {
+#define LINE_WRAP 60
+    if (WriteAlignment(prMSeq, NULL, MSAFILE_A2M, LINE_WRAP)) {
         Log(&rLog, LOG_FATAL, "Could not save alignment");
     } 
 
