@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: hhalign.cpp 290 2013-09-20 15:18:12Z fabian $
+ *  RCS $Id: hhalign.cpp 309 2016-06-13 14:10:11Z fabian $
  */
 
 /* hhalign.C: 
@@ -677,7 +677,7 @@ ProcessArguments(int argc, char** argv)
 extern "C" int 
 hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
         char **ppcSecndProf, int iSecndCnt, double *pdWeightsR,
-        double *dScore_p, hmm_light *prHMM,
+        double *dScore_p, hmm_light *prHMM, hmm_light *prHMM2,
         char *pcPrealigned1, char *pcRepresent1, 
         char *pcPrealigned2, char *pcRepresent2, 
         hhalign_para rHhalignPara, hhalign_scores *rHHscores, 
@@ -879,7 +879,7 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
         tL = strlen(ppcSecndProf[0]);
     }
     else {
-        tL = prHMM->L;
+        tL = prHMM2->L;
     }
     
 
@@ -942,7 +942,7 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
                and add pseudocounts etc. */
             t.cQT = 't';
             if (OK != ReadAndPrepare(INTERN_ALN_2_HMM,
-                                     ppcSecndProf, iSecndCnt, prHMM, 
+                                     ppcSecndProf, iSecndCnt, prHMM2, 
                                      pcPrealigned2, pcRepresent2, pdWeightsR, 
                                      infile, t)) {
                 sprintf(zcError, "%s:%s:%d: Problem Reading/Preparing t-profile (len=%d)\n",
@@ -1344,7 +1344,7 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
   hitlist.Reset();
   while (!hitlist.End()) 
       hitlist.ReadNext().Delete(); // Delete content of hit object
-  
+
   if (strucfile && par.wstruc>0) 
       {
           for (int i=0; i<q.L+2; i++){
@@ -1396,7 +1396,7 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
       t.ClobberGlobal();
   }
   hitlist.ClobberGlobal();
-  
+
   return iRetVal;
 
 } /* this is the end of hhalign() //end main */
