@@ -15,14 +15,14 @@
  ********************************************************************/
 
 /*
- * RCS $Id: hhalign.h 284 2013-06-12 10:10:11Z fabian $
+ * RCS $Id: hhalign.h 296 2014-10-07 12:15:41Z fabian $
  */
 
 
 extern int 
 hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL, 
         char **ppcSecndProf, int iSecndCnt, double *pdWeightsR, 
-        double *dScore_p, hmm_light *prHMM, 
+        double *dScore_p, hmm_light *prHMM, hmm_light *prHMM2, 
         char *pcPrealigned1, char *pcRepresent1,
         char *pcPrealigned2, char *pcRepresent2,
         hhalign_para rHhalignPara, hhalign_scores *rHHscores, 
