@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: hhfunc-C.h 290 2013-09-20 15:18:12Z fabian $
+ *  RCS $Id: hhfunc-C.h 309 2016-06-13 14:10:11Z fabian $
  */
 
 /*
@@ -29,6 +29,7 @@
 
 // hhfunc.C
 
+//#include "new_new.h" /* memory tracking */
 
 /**
  * AddBackgroundFrequencies()
@@ -218,7 +219,7 @@ AddBackgroundFrequencies(float **ppfFreq, float **ppfPseudoF, float **ppfPseudoT
  *
  * @param[in] iRnPtype
  * type of read/prepare 
- * enum {INTERN_ALN_2_HMM = 0, READ_ALN_2_HMM, READ_HMM_2_HMM};
+ * enum {INTERN_ALN_2_HMM = 0, READ_ALN_2_HMM, READ_HMM_2_HMM, INTERN_HMM_2_HMM};
  * @param[in] ppcProf 
  * alignment
  * @param[in] iCnt
@@ -1141,7 +1142,7 @@ readHMMWrapper(hmm_light *rHMM_p,
             } /* (0 <= iA < AMINOACIDS) */
             rHMM_p->seq[rHMM_p->ncons][i] = i2aa(iAmax);
         } /* (0 <= i < rHMM_p->L) */
-
+        rHMM_p->seq[rHMM_p->ncons][i] = '\0'; /* FS, r291 -> */
     } /* ncons not set */
 
 
