@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- * RCS $Id: hhmatrices-C.h 274 2012-04-24 23:28:24Z dave $
+ * RCS $Id: hhmatrices-C.h 316 2016-12-16 16:14:39Z fabian $
  */
 
 // Substitution matrices and their background frequencies
@@ -430,7 +430,7 @@ SetSubstitutionMatrix()
   //Precompute matrix R for amino acid pseudocounts:
   for (a=0; a<20; ++a)
     for (b=0; b<20; ++b)   
-      S[a][b] = log2(R[a][b]/pb[a]); // S[a][b] = log2(P(a,b)/P(a)/P(b))
+      S[a][b] = Log2(R[a][b]/pb[a]); // S[a][b] = log2(P(a,b)/P(a)/P(b))
   
   // Evaluate sequence identity underlying substitution matrix
   if (v>=3)
@@ -440,11 +440,11 @@ SetSubstitutionMatrix()
       float entropy_pb=0.0f;
       float mut_info=0.0f;
       for (a=0; a<20; ++a) id+=P[a][a];
-      for (a=0; a<20; ++a) entropy_pb-=pb[a]*log2(pb[a]);
+      for (a=0; a<20; ++a) entropy_pb-=pb[a]*Log2(pb[a]);
       for (a=0; a<20; ++a) 
 	  for (b=0; b<20; ++b) 
 	    {
-	      entropy-=P[a][b]*log2(R[a][b]);
+	      entropy-=P[a][b]*Log2(R[a][b]);
 	      mut_info += P[a][b]*S[a][b];
 	    }
       
@@ -538,7 +538,7 @@ SetRnaSubstitutionMatrix()
   //Precompute matrix R for amino acid pseudocounts:
   for (a=0; a<20; ++a)
     for (b=0; b<20; ++b)   
-      S[a][b] = log2(R[a][b]/pb[a]); // S[a][b] = log2(P(a,b)/P(a)/P(b))
+      S[a][b] = Log2(R[a][b]/pb[a]); // S[a][b] = log2(P(a,b)/P(a)/P(b))
   
   // Evaluate sequence identity underlying substitution matrix
   if (v>=3)
@@ -548,11 +548,11 @@ SetRnaSubstitutionMatrix()
       float entropy_pb=0.0f;
       float mut_info=0.0f;
       for (a=0; a<20; ++a) id+=P[a][a];
-      for (a=0; a<20; ++a) entropy_pb-=pb[a]*log2(pb[a]);
+      for (a=0; a<20; ++a) entropy_pb-=pb[a]*Log2(pb[a]);
       for (a=0; a<20; ++a) 
 	  for (b=0; b<20; ++b) 
 	    {
-	      entropy-=P[a][b]*log2(R[a][b]);
+	      entropy-=P[a][b]*Log2(R[a][b]);
 	      mut_info += P[a][b]*S[a][b];
 	    }
       
@@ -646,7 +646,7 @@ SetDnaSubstitutionMatrix()
   //Precompute matrix R for amino acid pseudocounts:
   for (a=0; a<20; ++a)
     for (b=0; b<20; ++b)   
-      S[a][b] = log2(R[a][b]/pb[a]); // S[a][b] = log2(P(a,b)/P(a)/P(b))
+      S[a][b] = Log2(R[a][b]/pb[a]); // S[a][b] = log2(P(a,b)/P(a)/P(b))
   
   // Evaluate sequence identity underlying substitution matrix
   if (v>=3)
@@ -656,11 +656,11 @@ SetDnaSubstitutionMatrix()
       float entropy_pb=0.0f;
       float mut_info=0.0f;
       for (a=0; a<20; ++a) id+=P[a][a];
-      for (a=0; a<20; ++a) entropy_pb-=pb[a]*log2(pb[a]);
+      for (a=0; a<20; ++a) entropy_pb-=pb[a]*Log2(pb[a]);
       for (a=0; a<20; ++a) 
 	  for (b=0; b<20; ++b) 
 	    {
-	      entropy-=P[a][b]*log2(R[a][b]);
+	      entropy-=P[a][b]*Log2(R[a][b]);
 	      mut_info += P[a][b]*S[a][b];
 	    }
       
@@ -739,7 +739,7 @@ SetSecStrucSubstitutionMatrix()
       for (B=0; B<NSSPRED; B++)
 	{
 	  P73[A][B][cf] = 1.-par.ssa + par.ssa*Ppred[cf*NSSPRED*NDSSP + B*NDSSP + A];
-	  S73[A][B][cf] = log2(P73[A][B][cf]);
+	  S73[A][B][cf] = Log2(P73[A][B][cf]);
 	}
 
   for (B=0; B<NSSPRED; B++)
@@ -750,7 +750,7 @@ SetSecStrucSubstitutionMatrix()
 	    sum=0;
 	    for (A=1; A<NDSSP; A++)
 	      sum += P73[A][B][cf] * P73[A][BB][ccf] * Pobs[A];
-	    S33[B][cf][BB][ccf] = log2(sum);
+	    S33[B][cf][BB][ccf] = Log2(sum);
 	  }  
 } /* this is the end of SetSecStrucSubstitutionMatrix() */
 
