@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- * RCS $Id: util-C.h 309 2016-06-13 14:10:11Z fabian $
+ * RCS $Id: util-C.h 316 2016-12-16 16:14:39Z fabian $
  */
 
 // Utility subroutines
@@ -30,6 +30,7 @@
 #endif
 #include <sys/time.h>
 //#include "new_new.h" /* memory tracking */
+#include "../config.h"
 
 /////////////////////////////////////////////////////////////////////////////////////
 // Arithmetics
@@ -51,8 +52,11 @@ inline int iround(double x) {return int(floor(x+0.5));}
 inline double fmean(double x, double y, double d) { return pow( (pow(x,d)+pow(y,d))/2 ,1./d);}
 
 // log base 2
-inline float log2(float x)  {return (x<=0? (float)(-100000):1.442695041*log(x));}
-inline float log10(float x) {return (x<=0? (float)(-100000):0.434294481*log(x));}
+//#ifndef CLUSTAL_OMEGA_HAVE_LOG2
+//#ifndef HAVE_LOG2
+inline float Log2(float x)  {return (x<=0? (float)(-100000):1.442695041*log(x));}
+inline float Log10(float x) {return (x<=0? (float)(-100000):0.434294481*log(x));}
+//#endif
 
 
 /////////////////////////////////////////////////////////////////////////////////////
@@ -243,7 +247,7 @@ inline float NormalizeToX(float* array, int length, float x, float* def_array=NU
 inline char* sprintg(float val, int w)
 {
   static char str[100];
-  float log10val = log10(fabs(val));
+  float log10val = Log10(fabs(val));
   int neg = (val<0? 1: 0);
   if (log10val >= w-neg-1 || -log10val > 3) 
     {
