@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: mymain.c 290 2013-09-20 15:18:12Z fabian $
+ *  RCS $Id: mymain.c 296 2014-10-07 12:15:41Z fabian $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -140,6 +140,7 @@ SetDefaultUserOpts(cmdline_opts_t *opts)
     opts->bIsProfile = FALSE;
     opts->aln_opts.bUseKimura = FALSE;
 	opts->aln_opts.bPercID = FALSE;
+    opts->aln_opts.pcHMMBatch = NULL;
 
     opts->iMaxNumSeq = INT_MAX;
     opts->iMaxSeqLen = INT_MAX;
@@ -358,6 +359,8 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
     struct arg_file *opt_hmm_in = arg_filen(NULL, "hmm-in", "<file>",
                                             /*min*/ 0, /*max*/ 128,
                                             "HMM input files");
+    struct arg_file *opt_hmm_batch = arg_file0(NULL, "hmm-batch", "<file>", /* FS, r291 -> */
+                                               "specify HMMs for individual sequences");
     struct arg_lit *opt_dealign = arg_lit0(NULL, "dealign",
                                            "Dealign input sequences");
     struct arg_file *opt_profile1 = arg_file0(NULL, "profile1,p1",
@@ -491,6 +494,7 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
     void *argtable[] = {rem_seq_input,
                         opt_seqin,
                         opt_hmm_in,
+                        opt_hmm_batch, /* FS, r291 -> */
                         opt_dealign,
                         opt_profile1,
                         opt_profile2,
@@ -785,6 +789,16 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
     }
 
 
+    /* HMM Batch, FS, r291 ->
+     */
+    user_opts->aln_opts.pcHMMBatch = NULL;
+    if (opt_hmm_batch->count>0){
+        user_opts->aln_opts.pcHMMBatch = CkStrdup(opt_hmm_batch->filename[0]);
+        if (! FileExists(user_opts->aln_opts.pcHMMBatch)){
+            Log(&rLog, LOG_FATAL, "File '%s' does not exist.", user_opts->aln_opts.pcHMMBatch);
+        }
+    }
+
     /* Pair distance method
      */
     if (opt_pairdist->count > 0) {
@@ -1058,7 +1072,7 @@ MyMain(int argc, char **argv)
         if (ReadSequences(prMSeq, cmdline_opts.pcSeqInfile,
                           cmdline_opts.iSeqType, cmdline_opts.iSeqInFormat,
                           cmdline_opts.bIsProfile, cmdline_opts.bDealignInputSeqs, 
-                          cmdline_opts.iMaxNumSeq, cmdline_opts.iMaxSeqLen)) {
+                          cmdline_opts.iMaxNumSeq, cmdline_opts.iMaxSeqLen, cmdline_opts.aln_opts.pcHMMBatch)) {
             Log(&rLog, LOG_FATAL, "Reading sequence file '%s' failed", cmdline_opts.pcSeqInfile);
         }
 #if TRACE
@@ -1106,7 +1120,7 @@ MyMain(int argc, char **argv)
         if (ReadSequences(prMSeqProfile1, cmdline_opts.pcProfile1Infile,
                           cmdline_opts.iSeqType,  cmdline_opts.iSeqInFormat,
                           cmdline_opts.bIsProfile, cmdline_opts.bDealignInputSeqs, 
-                          cmdline_opts.iMaxNumSeq, cmdline_opts.iMaxSeqLen)) {
+                          cmdline_opts.iMaxNumSeq, cmdline_opts.iMaxSeqLen, cmdline_opts.aln_opts.pcHMMBatch)) {
             Log(&rLog, LOG_FATAL, "Reading sequences from profile file '%s' failed",
                   cmdline_opts.pcProfile1Infile);
         }
@@ -1132,7 +1146,7 @@ MyMain(int argc, char **argv)
         if (ReadSequences(prMSeqProfile2, cmdline_opts.pcProfile2Infile,
                           cmdline_opts.iSeqType,  cmdline_opts.iSeqInFormat,
                           cmdline_opts.bIsProfile, cmdline_opts.bDealignInputSeqs, 
-                          cmdline_opts.iMaxNumSeq, cmdline_opts.iMaxSeqLen)) {
+                          cmdline_opts.iMaxNumSeq, cmdline_opts.iMaxSeqLen, cmdline_opts.aln_opts.pcHMMBatch)) {
             Log(&rLog, LOG_FATAL, "Reading sequences from profile file '%s' failed",
                   cmdline_opts.pcProfile2Infile);
         }
