@@ -14,7 +14,7 @@
  * formatted files. Derivative of msf.c; MSF is a pretty
  * generic interleaved format.   
  * 
- * RCS $Id: clustal.c 312 2016-07-14 16:57:39Z fabian $ (Original squid RCS Id: clustal.c,v 1.1 1999/07/15 22:26:53 eddy Exp)
+ * RCS $Id: clustal.c 315 2016-12-15 17:18:30Z fabian $ (Original squid RCS Id: clustal.c,v 1.1 1999/07/15 22:26:53 eddy Exp)
  */
 
 #include <stdbool.h>
@@ -291,12 +291,12 @@ WriteClustal(FILE *fp, MSA *msa)
 	      }
 	      /* printf("%*s") gives problems for unicode, FS, -> 290 */
 	      /*fprintf(fp, "%-*s\t%s\t%d\n", namelen+5, msa->sqname[idx], buf, piResCnt[idx]);*/
-	      fprintf(fp, "%s%*s %s\t%d\n", msa->sqname[idx], namelen+5-utf8len(msa->sqname[idx]), "", buf, piResCnt[idx]);
+	      fprintf(fp, "%s%*s %s\t%d\n", msa->sqname[idx], (int)(namelen+5-utf8len(msa->sqname[idx])), "", buf, piResCnt[idx]);
 	    }
 	    else {
 	      /* printf("%*s") gives problems for unicode, FS, -> 290 */
 	      /*fprintf(fp, "%-*s\t%s\n", namelen+5, msa->sqname[idx], buf);*/
-	      fprintf(fp, "%s%*s %s\n", msa->sqname[idx], namelen+5-utf8len(msa->sqname[idx]), "", buf);
+	      fprintf(fp, "%s%*s %s\n", msa->sqname[idx], (int)(namelen+5-utf8len(msa->sqname[idx])), "", buf);
 	    }
 #else
 	    fprintf(fp, "%*s %s\n", namelen, msa->sqname[idx], buf);
