@@ -336,7 +336,12 @@ FreeSequence(char *seq, SQINFO *sqinfo)
       free(sqinfo->sa);
     }
   }
-}
+  if (sqinfo->flags & SQINFO_CO){
+    if (NULL != sqinfo->co){ /* FS, r296 -> */
+      free(sqinfo->co);
+    }
+  }
+} /* this is the end of FreeSequence() */
 
 int
 SetSeqinfoString(SQINFO *sqinfo, char *sptr, int flag)
@@ -438,6 +443,7 @@ SeqinfoCopy(SQINFO *sq1, SQINFO *sq2)
   if (sq2->flags & SQINFO_TYPE)  sq1->type   = sq2->type;
   if (sq2->flags & SQINFO_SS)    sq1->ss     = Strdup(sq2->ss);
   if (sq2->flags & SQINFO_SA)    sq1->sa     = Strdup(sq2->sa);
+  if (sq2->flags & SQINFO_CO)    sq1->co     = Strdup(sq2->co);
 }
 
 /* Function: ToDNA()
@@ -1124,6 +1130,16 @@ ReadSeq(SQFILE *V, int format, char **ret_seq, SQINFO *sqinfo)
 #endif
 	sqinfo->flags |= SQINFO_SA;
       }
+      if (V->msa->co != NULL && V->msa->co[V->msa->lastidx] != NULL) {
+/* AW: stopping squid from dealigning sequences and corresponding info */
+#ifdef CLUSTALO
+          sqinfo->co = sre_strdup(V->msa->co[V->msa->lastidx], V->msa->alen);
+#else
+          MakeDealignedString(V->msa->aseq[V->msa->lastidx], V->msa->alen, 
+                              V->msa->co[V->msa->lastidx], &(sqinfo->co));          
+#endif
+	sqinfo->flags |= SQINFO_CO;
+      } /* co */
       V->msa->lastidx++;
     } 
   else {
@@ -1236,6 +1252,9 @@ SeqfileFormat(FILE *fp)
 	      strncmp(buf, "!!NA_SEQUENCE", 13) == 0)
 	    { fmt = SQFILE_GCG; goto DONE; }
 
+	  if (strncmp(buf, "# DUBLIN 1.", 11) == 0) /* -> r296, FS */
+	    { fmt = MSAFILE_DUBLIN; goto DONE; }
+
 	  if (strncmp(buf, "# STOCKHOLM 1.", 14) == 0)
 	    { fmt = MSAFILE_STOCKHOLM; goto DONE; }
 
