@@ -24,7 +24,7 @@
  *      MSAFree(msa);
  *   }
  * 
- * RCS $Id: stockholm.c 217 2011-03-19 10:27:10Z andreas $ (Original squid RCS Id: stockholm.c,v 1.7 2002/10/12 04:40:36 eddy Exp)
+ * RCS $Id: stockholm.c 297 2014-10-31 13:02:37Z fabian $ (Original squid RCS Id: stockholm.c,v 1.7 2002/10/12 04:40:36 eddy Exp)
  */
 #include <stdio.h>
 #include <string.h>
@@ -157,6 +157,89 @@ alignment file, right?), please either:\n\
   return msa;
 }
 
+/* Function: ReadDublin()
+ * Date:     2014-10-15
+ *
+ * Purpose:  Parse the next sequences from an open Dublin
+ *           format file. Return the sequences, or
+ *           NULL if there are no more sequences in the file.
+ *
+ * Args:     afp  - open alignment file
+ *
+ * Returns:  MSA *   - an alignment object. 
+ *                     caller responsible for an MSAFree() 
+ *           NULL if no more alignments
+ *
+ * Diagnostics:
+ *           Will Die() here with a (potentially) useful message
+ *           if a parsing error occurs 
+ */
+MSA *
+ReadDublin(MSAFILE *afp)
+{
+  MSA   *msa;
+  char  *s;
+  int    status;
+
+  if (feof(afp->f)) return NULL;
+
+  /* Initialize allocation of the MSA.
+   */
+  msa = MSAAlloc(10, 0);
+
+  /* Check the magic Dublin header line.
+   * We have to skip blank lines here, else we perceive
+   * trailing blank lines in a file as a format error when
+   * reading in multi-record mode.
+   */
+  do {
+    if ((s = MSAFileGetLine(afp)) == NULL) {
+      MSAFree(msa);
+      return NULL;
+    }
+  } while (IsBlankline(s));
+
+  if (strncmp(s, "# DUBLIN 1.", 11) != 0)
+    Die("\
+File %s doesn't appear to be in Dublin format.\n", 
+	afp->fname);
+
+  /* Read the alignment file one line at a time.
+   */
+  while ((s = MSAFileGetLine(afp)) != NULL) 
+    {
+      while (*s == ' ' || *s == '\t') s++;  /* skip leading whitespace */
+
+      if (*s == '#') {
+	if      (strncmp(s, "#=GF", 4) == 0)   status = parse_gf(msa, s);
+	else if (strncmp(s, "#=GS", 4) == 0)   status = parse_gs(msa, s);
+	else if (strncmp(s, "#=GC", 4) == 0)   status = parse_gc(msa, s);
+	else if (strncmp(s, "#=GR", 4) == 0)   status = parse_gr(msa, s);
+	else                                   status = parse_comment(msa, s);
+      } 
+      else if (strncmp(s, "//",   2) == 0)   break;
+      else if (*s == '\n')                   continue;
+      else                                   status = parse_sequence(msa, s);
+
+      if (status == 0)  
+	Die("Dublin format parse error: line %d of file %s while reading alignment %s",
+	    afp->linenumber, afp->fname, msa->name == NULL? "" : msa->name);
+    }
+
+  if (s == NULL && msa->nseq != 0)
+    Die ("Didn't find // at end of alignment %s", msa->name == NULL ? "" : msa->name);
+
+  if (s == NULL && msa->nseq == 0) { 
+    				/* probably just some junk at end of file */
+      MSAFree(msa); 
+      return NULL; 
+    }
+  
+  MSAVerifyParseDub(msa);
+  return msa;
+
+} /* this is the end of ReadDublin() */
+
 
 /* Function: WriteStockholm()
  * Date:     SRE, Mon May 31 19:15:22 1999 [St. Louis]
@@ -579,6 +662,20 @@ parse_gr(MSA *msa, char *buf)
 	}
       msa->salen[seqidx] = sre_strcat(&(msa->sa[seqidx]), msa->salen[seqidx], text, len);
     }
+  else if (strcmp(featurename, "CO") == 0)
+    {
+      if (msa->co == NULL)
+	{
+	  msa->co    = MallocOrDie(sizeof(char *) * msa->nseqalloc);
+	  msa->colen = MallocOrDie(sizeof(int)    * msa->nseqalloc);
+	  for (j = 0; j < msa->nseqalloc; j++) 
+	    {
+	      msa->co[j]    = NULL;
+	      msa->colen[j] = 0;
+	    }
+	}
+      msa->colen[seqidx] = sre_strcat(&(msa->co[seqidx]), msa->colen[seqidx], text, len);
+    }
   else 
     MSAAppendGR(msa, featurename, seqidx, text);
 
